<?php
/**
 * @package WordPress
 * @subpackage listio
 */

/**
 * Function that sends email message from contact agent form
 */
if( !function_exists('listio_send_message_to_agent') ): 
    function listio_send_message_to_agent() {
        check_ajax_referer('agent_message_ajax_nonce', 'security');

        $allowed_html = array();
        $agent_email = isset($_POST['agent_email']) ? sanitize_email($_POST['agent_email']) : '';
        $client_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $client_email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $client_phone = isset($_POST['phone']) ? sanitize_text_field($_POST['phone']) : '';
        $client_subject = isset($_POST['subject']) ? sanitize_text_field($_POST['subject']) : '';
        $client_message = isset($_POST['message']) ? sanitize_text_field($_POST['message']) : '';
        $p_info_title = isset($_POST['p_info_title']) ? sanitize_text_field($_POST['p_info_title']) : '';
        $p_info_link = isset($_POST['p_info_link']) ? sanitize_text_field($_POST['p_info_link']) : '';

        

        if(empty($client_name) || empty($client_email) || empty($client_phone) || empty($client_subject) || empty($client_message)) {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Your message failed to be sent. Please check your fields.', 'listio')));
            exit();
        }

        $body = '';
        if($p_info_title != '' && $p_info_link != '') {
            $body .= esc_html__('You received the following message from ', 'listio');
            $body .= $client_name . ' [Phone number: ' . $client_phone . ']' . "\n\n";
            $body .= esc_html__('regarding a property you listed: ', 'listio') . "\n";
            $body .=  $p_info_title . ' [ ' . $p_info_link . ' ]' . "\n\n";
            $body .= $client_message;
        } else {
            $body .= esc_html__('You received the following message from ', 'listio');
            $body .= $client_name . ' [Phone number: ' . $client_phone . ']' . "\n\n";
            $body .= $client_message;
        }

        $headers = 'From: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'Reply-To: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        $send = wp_mail(
            $agent_email,
            sprintf( esc_html__('[%s Message from client] %s', 'listio'), get_option('blogname'), $client_subject ),
            $body,
            $headers
        );

        if($send) {
            echo json_encode(array('sent'=>true, 'message'=>esc_html__('Your message was successfully sent.', 'listio')));
            exit();
        } else {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Your message failed to be sent.', 'listio')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_listio_send_message_to_agent', 'listio_send_message_to_agent' );
add_action( 'wp_ajax_listio_send_message_to_agent', 'listio_send_message_to_agent' );


/**
 * Function that sends email message from contact page form
 */
if( !function_exists('listio_send_message_to_company') ): 
    function listio_send_message_to_company() {
        check_ajax_referer('contact_page_ajax_nonce', 'security');

        $company_email = isset($_POST['company_email']) ? sanitize_text_field($_POST['company_email']) : '';
        $client_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $client_email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $client_subject = isset($_POST['subject']) ? sanitize_text_field($_POST['subject']) : '';
        $client_message = isset($_POST['message']) ? sanitize_text_field($_POST['message']) : '';


        if(empty($client_name) || empty($client_email) || empty($client_subject) || empty($client_message)) {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Your message failed to be sent. Please check your fields.', 'listio')));
            exit();
        }

        $company_email = explode(',', $company_email);
        $headers = 'From: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'Reply-To: ' . $client_name . '  <' . $client_email . '>' . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        $send = wp_mail(
            $company_email,
            sprintf( esc_html__('[%s Message from client] %s', 'listio'), get_option('blogname'), $client_subject ),
            $client_message,
            $headers
        );

        if($send) {
            echo json_encode(array('sent'=>true, 'message'=>esc_html__('Your message was successfully sent.', 'listio')));
            exit();
        } else {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Your message failed to be sent.', 'listio')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_listio_send_message_to_company', 'listio_send_message_to_company' );
add_action( 'wp_ajax_listio_send_message_to_company', 'listio_send_message_to_company' );



if( !function_exists('listio_email_payment_to_admin') ):
    function listio_email_payment_to_admin($prop_id, $agent_id, $is_upgrade) {
        $headers = 'From: noreply  <noreply@' . $_SERVER['HTTP_HOST'] . '>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
     
        if($is_upgrade == 1) {
            $subject = sprintf(esc_html__('[%s] Listing Upgraded to Featured', 'listio'), get_option('blogname'));
            $message = sprintf(esc_html__('You have a new featured listing on %s.', 'listio'), get_option('blogname')) . "\r\n\r\n";
        } else {
            $subject = sprintf(esc_html__('[%s] New Paid Submission', 'listio'), get_option('blogname'));
            $message = sprintf(esc_html__('You have a new paid submission on %s.', 'listio'), get_option('blogname')) . "\r\n\r\n";
        }
        $message .= sprintf(esc_html__('Property title: %s','listio'), get_the_title($prop_id)) . "\r\n\r\n";
        $message .= sprintf(esc_html__('Agent: %s','listio'), get_the_title($agent_id)) . "\r\n";

        wp_mail(get_option('admin_email'), $subject, $message, $headers);
    }
endif;

if( !function_exists('listio_update_agent_membership') ):
    function listio_update_agent_membership($agent_id, $plan_id, $is_free = 0) {
        $plan_listings          = get_post_meta($plan_id, 'membership_submissions_no', true);
        $plan_unlimited         = get_post_meta($plan_id, 'membership_unlim_submissions', true);
        $plan_featured_listings = get_post_meta($plan_id, 'membership_featured_submissions_no', true);
        $agent_email            = get_post_meta($agent_id, 'agent_email', true);

        update_post_meta($agent_id, 'agent_plan', $plan_id);
        update_post_meta($agent_id, 'agent_plan_listings', $plan_listings);
        update_post_meta($agent_id, 'agent_plan_unlimited', $plan_unlimited);
        update_post_meta($agent_id, 'agent_plan_featured', $plan_featured_listings);

        $time = time(); 
        $date = date('Y-m-d H:i:s',$time); 
        update_post_meta($agent_id, 'agent_plan_activation', $date);

        if($is_free == 0) {
            listio_insert_invoice('Membership Plan', $plan_id, $agent_id, 0, 0);
        }

        $headers = 'From: noreply  <noreply@' . $_SERVER['HTTP_HOST'] . '>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();

        $subject = sprintf(esc_html__('[%s] Membership Plan Activated', 'listio'), get_option('blogname'));
        $message = sprintf(esc_html__('You have a new membership plan on %s is activated.', 'listio'), get_option('blogname')) . "\r\n\r\n";
        $message .= sprintf(esc_html__('Membership Type: %s','listio'), get_the_title($plan_id)) . "\r\n";

        wp_mail($agent_email, $subject, $message, $headers);
    }
endif;



if( !function_exists('listio_notify_agent_on_publish') ): 
    function listio_notify_agent_on_publish( $ID, $post ) {
        $author = $post->post_author;
        $name = get_the_author_meta( 'display_name', $author );
        $email = get_the_author_meta( 'user_email', $author );
        $title = $post->post_title;
        $permalink = get_permalink( $ID );
        $edit = get_edit_post_link( $ID, '' );

        $to[] = sprintf( '%s <%s>', $name, $email );
        $message = sprintf ( esc_html__('Congratulations, %s! Your property "%s" has been published.', 'listio') . "\n\n", $name, $title );
        $message .= sprintf( esc_html__('View: %s', 'listio'), $permalink );
        $headers = 'From: noreply  <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        wp_mail(
            $to,
            sprintf( esc_html__('[%s] Property Published: %s', 'listio'), get_option('blogname'), $title ),
            $message,
            $headers
        );
    }
endif;
$listio_notifications_settings = get_option('listio_notifications_settings');
$notify_agent = isset($listio_notifications_settings['listio_notify_agent_publish_field']) ? $listio_notifications_settings['listio_notify_agent_publish_field'] : '';
if($notify_agent == 1) {
    add_action('publish_property', 'listio_notify_agent_on_publish', 10, 2);
}


/**
 * Function that sends email message to admin for reporting a property
 */
if( !function_exists('listio_report_property') ): 
    function listio_report_property() {
        check_ajax_referer('report_property_ajax_nonce', 'security');

        $reason       = isset($_POST['reason']) ? sanitize_text_field($_POST['reason']) : '';
        $report_title = isset($_POST['report_title']) ? sanitize_text_field($_POST['report_title']) : '';
        $report_link  = isset($_POST['report_link']) ? sanitize_text_field($_POST['report_link']) : '';

        if(empty($reason)) {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Please describe a reason.', 'listio')));
            exit();
        }

        $body = '';
        $body .= esc_html__('You received a report regarding this property listing:', 'listio') . "\n\n";
        $body .=  $report_title . ' [ ' . $report_link . ' ]' . "\n\n";
        $body .=  esc_html__('Reason: ', 'listio') . "\n\n";
        $body .= $reason;

        $headers = 'From: noreply  <noreply@' . $_SERVER['HTTP_HOST'] . '>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        $send = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('%s - Property Listing Report', 'listio'), get_option('blogname') ),
            $body,
            $headers
        );

        if($send) {
            echo json_encode(array('sent'=>true, 'message'=>esc_html__('Your report was successfully submited.', 'listio')));
            exit();
        } else {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Your report failed to be submited.', 'listio')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_listio_report_property', 'listio_report_property' );
add_action( 'wp_ajax_listio_report_property', 'listio_report_property' );

/**
 * Admin notification when new property submitted
 */

if( !function_exists('listio_admin_property_notification') ): 
    function listio_admin_property_notification($property_title, $agent_id, $edit) {
        if($edit == '') {
            $message = sprintf( esc_html__('A new property was submitted on %s:','listio'), get_option('blogname') ) . "\r\n\r\n";
            $message .= sprintf( esc_html__('Property title: %s','listio'), esc_html($property_title) ) . "\r\n\r\n";
            $message .= sprintf( esc_html__('Agent: %s','listio'), get_the_title($agent_id) ) . "\r\n";
            $headers = 'From: noreply  <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n" .
                    'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
            wp_mail(
                get_option('admin_email'),
                sprintf(esc_html__('[%s] Property Submitted','listio'), get_option('blogname') ),
                $message,
                $headers
            );
        } else {
            $message = sprintf( esc_html__('A property was updated on %s:','listio'), get_option('blogname') ) . "\r\n\r\n";
            $message .= sprintf( esc_html__('Property title: %s','listio'), esc_html($property_title) ) . "\r\n\r\n";
            $message .= sprintf( esc_html__('Agent: %s','listio'), get_the_title($agent_id) ) . "\r\n";
            $headers = 'From: noreply  <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n" .
                    'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
            wp_mail(
                get_option('admin_email'),
                sprintf(esc_html__('[%s] Property Updated','listio'), get_option('blogname') ),
                $message,
                $headers
            );
        }
    }
endif;


/**
 * Sign Up notifications
 */
if( !function_exists('listio_signup_notifications') ): 
    function listio_signup_notifications($user, $user_pass = '') {
        $new_user = new WP_User($user);

        $user_login = stripslashes($new_user->user_login);
        $user_email = stripslashes($new_user->user_email);
        $user_first_name = stripslashes($new_user->first_name);

        $message = sprintf( esc_html__('New user Sign Up on %s:','listio'), get_option('blogname') ) . "\r\n\r\n";
        $message .= sprintf( esc_html__('Username: %s','listio'), esc_html($user_login) ) . "\r\n\r\n";
        $message .= sprintf( esc_html__('E-mail: %s','listio'), esc_html($user_email) ) . "\r\n";
        $headers = 'From: noreply  <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        wp_mail(
            get_option('admin_email'),
            sprintf(esc_html__('[%s] New User Sign Up','listio'), get_option('blogname') ),
            $message,
            $headers
        );

        if(empty($user_pass)) return;

        $message  = sprintf( esc_html__('Welcome, %s!','listio'), esc_html($user_first_name) ) . "\r\n\r\n";
        $message .= esc_html__('Thank you for signing up with us. Your new account has been setup and you can now login using the details below.','listio') . "\r\n\r\n";
        $message .= sprintf( esc_html__('Username: %s','listio'), esc_html($user_login) ) . "\r\n";
        $message .= sprintf( esc_html__('Password: %s','listio'), esc_html($user_pass) ) . "\r\n\r\n";
        $message .= esc_html__('Thank you,','listio') . "\r\n";
        $message .= sprintf( esc_html__('%s Team','listio'), get_option('blogname') );
        $headers = 'From: noreply  <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n" .
                'Reply-To: noreply@' . $_SERVER['HTTP_HOST'] . "\r\n" .
                'X-Mailer: PHP/' . phpversion();
        wp_mail(
            esc_html($user_email),
            sprintf( esc_html__('[%s] Your username and password','listio'), get_option('blogname') ),
            $message,
            $headers
        );
    }
endif;

/**
 * Forgot Password Function
 */
if( !function_exists('listio_forgot_pass_form') ): 
    function listio_forgot_pass_form() {
        global $wpdb, $wp_hasher;

        $forgot_email = isset($_POST['forgot_email']) ? sanitize_email($_POST['forgot_email']) : '';

        if($forgot_email == '') {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Email field is empty!','listio')));
            exit();
        }

        $user_input = trim($forgot_email);

        if(strpos($user_input, '@')) {
            $user_data = get_user_by('email', $user_input);
            if(empty($user_data)) {
                echo json_encode(array('sent'=>false, 'message'=>esc_html__('Invalid email address!','listio')));
                exit();
            }
        } else {
            $user_data = get_user_by('login', $user_input);
            if(empty($user_data)) {
                echo json_encode(array('sent'=>false, 'message'=>esc_html__('Invalid username!','listio')));
                exit();
            }
        }

        $user_login = $user_data->user_login;
        $user_email = $user_data->user_email;

        $key = wp_generate_password( 20, false );
        do_action( 'retrieve_password_key', $user_login, $key );

        if ( empty( $wp_hasher ) ) {
            require_once ABSPATH . WPINC . '/class-phpass.php';
            $wp_hasher = new PasswordHash( 8, true );
        }
        $hashed = time() . ':' . $wp_hasher->HashPassword( $key );
        $wpdb->update( $wpdb->users, array( 'user_activation_key' => $hashed ), array( 'user_login' => $user_login ) );

        $headers = 'From: No Reply <noreply@'.$_SERVER['HTTP_HOST'].'>' . "\r\n";
        $message = esc_html__('Someone has asked to reset the password for the following site and username.', 'listio') . "\r\n\r\n";
        $message .= get_option('siteurl') . "\r\n\r\n";
        $message .= sprintf(esc_html__('Username: %s', 'listio'), $user_login) . "\r\n\r\n";
        $message .= esc_html__('To reset your password visit the following address, otherwise just ignore this email and nothing will happen.', 'listio') . "\r\n\r\n";
        $message .= network_site_url("?action=rp&key=$key&login=" . rawurlencode($user_login), 'login') . "\r\n";

        if($message && !wp_mail($user_email, esc_html__('Password Reset Request','listio'), $message,  $headers)) {
            echo json_encode(array('sent'=>false, 'message'=>esc_html__('Email failed to send for some unknown reason.','listio')));
            exit();
        } else {
            echo json_encode(array('sent'=>true, 'message'=>esc_html__('An email with password reset instructions was sent to you.','listio')));
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_listio_forgot_pass_form', 'listio_forgot_pass_form');
add_action('wp_ajax_listio_forgot_pass_form', 'listio_forgot_pass_form');

?>